==> mandrel-23.0.0.0-Final.tar.gz: mandrel-mandrel-23.0.0.0-Final/espresso/src/com.oracle.truffle.espresso.processor/src/com/oracle/truffle/espresso/processor/builders/SignatureBuilder.java <==
/*
 * Copyright (c) 2021, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.truffle.espresso.processor.builders;

import java.util.LinkedList;
import java.util.List;

public final class SignatureBuilder extends AbstractCodeBuilder {
    private final String name;
    private final List<String> params = new LinkedList<>();

    public SignatureBuilder(String name) {
        this.name = name;
    }

    public SignatureBuilder addParam(String param) {
        params.add(param);
        return this;
    }

    @Override
    void buildImpl(IndentingStringBuilder sb) {
        sb.append(name);
        sb.append(PAREN_OPEN).join(", ", params).append(PAREN_CLOSE);
    }
}

==> mandrel-23.1.5.0-Final.tar.gz: mandrel-mandrel-23.1.5.0-Final/espresso/src/com.oracle.truffle.espresso.processor/src/com/oracle/truffle/espresso/processor/builders/SignatureBuilder.java <==
/*
 * Copyright (c) 2021, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.truffle.espresso.processor.builders;

import java.util.LinkedList;
import java.util.List;

public final class SignatureBuilder extends AbstractCodeBuilder {
    private String name;
    private final List<VariableBuilder> params = new LinkedList<>();

    public SignatureBuilder() {
    }

    public SignatureBuilder withName(String callName) {
        this.name = callName;
        return this;
    }

    public SignatureBuilder addParam(String param) {
        params.add(new VariableBuilder().withName(param));
        return this;
    }

    public SignatureBuilder addParam(VariableBuilder variableBuilder) {
        params.add(variableBuilder);
        return this;
    }

    @Override
    void buildImpl(IndentingStringBuilder sb) {
        if (name != null) {
            sb.append(name);
        }
        sb.append(PAREN_OPEN);

        boolean first = true;
        for (VariableBuilder v : params) {
            if (first) {
                first = false;
            } else {
                sb.appendSpace(',');
            }
            v.buildImpl(sb);
        }

        sb.append(PAREN_CLOSE);
    }

    @Override
    public String toString() {
        IndentingStringBuilder isb = new IndentingStringBuilder(0);
        buildImpl(isb);
        return isb.toString();
    }
}
